@@ -136,8 +136,8 @@ class MainLog(BaseLog):
                         """加入日志平台对内流水日志"""
                         response_data = is_json(str_ret)
                         if response_data:
-                            if str(response_data.get('code')) or str(response_data.get(u'code')):
-                                response_code = str(response_data.get('code') or response_data.get(u'code'))
+                            if str(response_data.get('code', "")) or str(response_data.get(u'code', "")):
+                                response_code = str(response_data.get('code', "")) or str(response_data.get(u'code', ""))
                             elif response_data.get('head'):
                                 response_code = str(response_data.get('head').get('code'))
                             elif response_data.get(u'head'):
